@@ -19,7 +19,7 @@ class InstanceGroup(HasCreate, base.Base):
 
     def payload(self, **kwargs):
         payload = PseudoNamespace(name=kwargs.get('name') or 'Instance Group - {}'.format(random_title()))
-        fields = ('policy_instance_percentage', 'policy_instance_minimum', 'policy_instance_list', 'is_container_group')
+        fields = ('policy_instance_percentage', 'policy_instance_minimum', 'policy_instance_list', 'is_container_group', 'max_forks', 'max_concurrent_jobs')
         update_payload(payload, fields, kwargs)
 
         set_payload_foreign_key_args(payload, ('credential',), kwargs)
