@@ -42,6 +42,9 @@ class WorkflowJobTemplate(HasCopy, HasCreate, HasNotifications, HasSurvey, Unifi
             "ask_inventory_on_launch",
             "ask_scm_branch_on_launch",
             "ask_limit_on_launch",
+            "ask_labels_on_launch",
+            "ask_skip_tags_on_launch",
+            "ask_tags_on_launch",
             "limit",
             "scm_branch",
             "survey_enabled",
